"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PluginTerminal = void 0;
const tslib_1 = require("tslib");
const server_1 = require("@dash4/server");
const terminal_emulator_1 = require("@dash4/terminal-emulator");
const fs_1 = tslib_1.__importDefault(require("fs"));
const path_1 = tslib_1.__importDefault(require("path"));
const uuid_1 = require("uuid");
tslib_1.__exportStar(require("./jest-commands"), exports);
const processCwd = fs_1.default.realpathSync(process.cwd());
class PluginTerminal extends server_1.Dash4Plugin {
    constructor({ dark = true, width, height, title, subtitle, cmd, cwd, autostart = false, allowedCommands, }) {
        super({
            dark,
            width,
            name: 'PluginTerminal',
            lowerCaseName: 'plugin-terminal',
        });
        this._terminalLog = '';
        this._stopProcessingTriggered = false;
        this.connected = () => {
            if (!this.on) {
                return;
            }
            this.on('connected', this._handleConnected);
            this.on('start', this._start);
            this.on('stop', this._stop);
            this.on('clean', this._clean);
            this.on('command', this._appendCommand);
            this.on('command-input', this._appendCommandInput);
        };
        this._handleConnected = () => {
            this.send('connected', this._terminalLog);
            if (this._stopProcessingTriggered) {
                this.send('stopped');
            }
        };
        this._handleTermStopProcessing = () => {
            this._stopProcessingTriggered = true;
            this.send('stopped');
        };
        this._getCommandById = (commandId) => {
            if (!this._allowedCommands || !this._allowedCommands[commandId]) {
                return;
            }
            return this._allowedCommands[commandId];
        };
        this._appendCommand = (commandId) => {
            const command = this._getCommandById(commandId);
            if (!command) {
                return;
            }
            const out = command.terminalOutput || command.keyCode.toString();
            this._terminalLog += out;
            if (!this._term) {
                return;
            }
            this._term.write(out);
        };
        this._appendCommandInput = ({ value, commandId }) => {
            const command = this._getCommandById(commandId);
            if (!command || !command.input || !value || !commandId) {
                return;
            }
            const out = command.input(value);
            this._terminalLog += out;
            if (!this._term) {
                return;
            }
            this._term.write(out);
            setTimeout(() => {
                if (!this._term) {
                    return;
                }
                this._term.write('\r');
            }, 100);
        };
        this._recieveData = (data) => {
            this._terminalLog += data.toString();
            if (!this.send) {
                return;
            }
            this.send('recieve', data.toString());
        };
        this._kill = () => {
            if (!this._term) {
                return;
            }
            this._term.kill();
        };
        this._write = (cmd) => {
            if (!this._term) {
                return;
            }
            this._term.write(cmd);
        };
        this._stop = () => {
            this._terminalLog = '';
            this._kill();
        };
        this._clean = () => {
            this._write('\x1Bc');
            this._terminalLog = '';
        };
        this._start = () => tslib_1.__awaiter(this, void 0, void 0, function* () {
            this.create();
            this._stopProcessingTriggered = false;
            this._write(`${this._cmd}\r`);
        });
        this._cmd = cmd;
        this._cwd = cwd ? path_1.default.join(processCwd, cwd) : processCwd;
        this._autostart = autostart;
        this._height = height;
        this._title = title;
        this._subtitle = subtitle;
        if (allowedCommands) {
            allowedCommands.forEach((allowedCommand) => {
                if (!this._allowedCommands) {
                    this._allowedCommands = {};
                }
                this._allowedCommands[uuid_1.v1()] = allowedCommand;
            });
        }
        if (this._autostart) {
            this._start();
        }
    }
    create() {
        this._term = terminal_emulator_1.terminalEmulator({
            cwd: this._cwd,
            onData: this._recieveData,
            onStopProcessing: this._handleTermStopProcessing,
        });
    }
    get clientConfig() {
        const allowedCommands = {};
        Object.keys(this._allowedCommands || {}).forEach((commandId) => {
            if (!this._allowedCommands || !this._allowedCommands[commandId]) {
                return;
            }
            allowedCommands[commandId] = {
                keyCode: this._allowedCommands[commandId].keyCode,
                title: this._allowedCommands[commandId].title,
                hasInput: typeof this._allowedCommands[commandId].input === 'function',
            };
        });
        return {
            cmd: this._cmd,
            cwd: this._cwd,
            allowedCommands,
            height: this._height,
            title: this._title,
            subtitle: this._subtitle,
        };
    }
    get clientFiles() {
        return [path_1.default.join(__dirname, '../../dist/plugins/plugin-terminal/main.js')];
    }
}
exports.PluginTerminal = PluginTerminal;
//# sourceMappingURL=index.js.map